package models

import (
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

// 👈 SignUpInput struct
type SignUpInput struct {
	Name             string    `json:"name" bson:"name" binding:"required"`
	Email            string    `json:"email" bson:"email" binding:"required"`
	Password         string    `json:"password" bson:"password" binding:"required,min=8"`
	PasswordConfirm  string    `json:"passwordConfirm" bson:"passwordConfirm,omitempty" binding:"required"`
	Role             string    `json:"role" bson:"role"`
	VerificationCode string    `json:"verificationCode,omitempty" bson:"verificationCode,omitempty"`
	Verified         bool      `json:"verified" bson:"verified"`
	CreatedAt        time.Time `json:"created_at" bson:"created_at"`
	UpdatedAt        time.Time `json:"updated_at" bson:"updated_at"`
}

// 👈 SignInInput struct
type SignInInput struct {
	Email    string `json:"email" bson:"email" binding:"required"`
	Password string `json:"password" bson:"password" binding:"required"`
}

// 👈 DBResponse struct
type DBResponse struct {
	ID               primitive.ObjectID `json:"id" bson:"_id"`
	Name             string             `json:"name" bson:"name"`
	Email            string             `json:"email" bson:"email"`
	Password         string             `json:"password" bson:"password"`
	PasswordConfirm  string             `json:"passwordConfirm,omitempty" bson:"passwordConfirm,omitempty"`
	Role             string             `json:"role" bson:"role"`
	VerificationCode string             `json:"verificationCode,omitempty" bson:"verificationCode"`
	Verified         bool               `json:"verified" bson:"verified"`
	CreatedAt        time.Time          `json:"created_at" bson:"created_at"`
	UpdatedAt        time.Time          `json:"updated_at" bson:"updated_at"`
}

// 👈 UserResponse struct
type UserResponse struct {
	ID        primitive.ObjectID `json:"id,omitempty" bson:"_id,omitempty"`
	Name      string             `json:"name,omitempty" bson:"name,omitempty"`
	Email     string             `json:"email,omitempty" bson:"email,omitempty"`
	Role      string             `json:"role,omitempty" bson:"role,omitempty"`
	CreatedAt time.Time          `json:"created_at" bson:"created_at"`
	UpdatedAt time.Time          `json:"updated_at" bson:"updated_at"`
}

func FilteredResponse(user *DBResponse) UserResponse {
	return UserResponse{
		ID:        user.ID,
		Email:     user.Email,
		Name:      user.Name,
		Role:      user.Role,
		CreatedAt: user.CreatedAt,
		UpdatedAt: user.UpdatedAt,
	}
}
